# Latest Kemendikbud News
this package will get the latest news from Indonesian Ministry of Education and Culture (Kemdikbud)

## How it Work?
This package will scrape from [Kemendikbud](https://kemendikbud.go.id) to get latest news from kemendikbud website
This package will use BeautifulSoup4 and Requests, to produce output in the form of JSON that is ready to be used in web or mobile applications

## Author
Irfan Basyar